@@ -14,21 +14,21 @@ __copyright__ = """
 """
 __license__ = "Apache 2.0"
 
-import requests
-import json
-import sys
-import pkg_resources
 import argparse
-import os
 import datetime
+import json
+import os
+import sys
 import webbrowser
-from argofloats import argofloats
-import pandas as pd
-from rapidfuzz import fuzz
 from collections import Counter
+
+import pandas as pd
+import pkg_resources
+import requests
+from argofloats import argofloats
 from bs4 import BeautifulSoup
 from dateutil.relativedelta import *
-
+from rapidfuzz import fuzz
 
 headers = {
     "authority": "ocean-systems.uc.r.appspot.com",
@@ -126,6 +126,7 @@ def read_from_parser(args):
 
 def sitelist(sname, status):
     sid_list = []
+    hobo_list = []
     status_list = []
     response = requests.get("https://ocean-systems.uc.r.appspot.com/api/sites")
     stat_type = ["maintenance", "deployed", "shipped", "lost"]
@@ -136,20 +137,33 @@ def sitelist(sname, status):
     for items in response.json():
         if items["sensorId"] is not None:
             if status is not None and items["status"] == status:
-                sid_list.append({items["name"]: items["id"]})
+                sid_list.append([items["name"], items["id"]])
                 status_list.append(items["status"])
             elif status is None:
-                sid_list.append({items["name"]: items["id"]})
+                sid_list.append([items["name"], items["id"]])
                 status_list.append(items["status"])
-    for site in sid_list:
-        for name, sid in site.items():
-            if sname is not None:
-                rat = fuzz.ratio(sname.lower(), name.lower())
-                if sname.lower() in name.lower() or rat > 75:
-                    print(f"{name}: {sid}")
-            elif sname is None:
-                print(f"{name}: {sid}")
-    print("\n" + f"Found a total of {len(sid_list)} sites with spotters" + "\n")
+        elif items["hasHobo"] is True:
+            hobo_list.append([items["name"], items["id"]])
+    if sname is not None:
+        for site in sid_list:
+            rat = fuzz.ratio(sname.lower(), site[0].lower())
+            if sname.lower() in site[0].lower() or rat > 75:
+                print(f"{site[0]}: {site[1]}")
+    elif sname is None:
+        if sid_list:
+            print("\n" + "================Spotter Locations================")
+            print(
+                "\n".join([" : ".join([str(cell) for cell in row])
+                          for row in sid_list])
+            )
+    if hobo_list and sname is None:
+        print("\n" + "================Hobo Sensor Locations================")
+        print("\n".join([" : ".join([str(cell) for cell in row])
+              for row in hobo_list]))
+    print(
+        "\n" + f"Found a total of {len(sid_list)} sites with spotters" + "\n")
+    print(
+        "\n" + f"Found a total of {len(hobo_list)} sites with hobo logger" + "\n")
     print("Spotter status distribution :")
     print(json.dumps(Counter(status_list)))
 
@@ -159,53 +173,132 @@ def sitelist_from_parser(args):
 
 
 # Site alert
-def sitealert(level):
+def sitealert(level, device):
     sid_list = []
+    hobo_list = []
+    overall_list = []
     status_list = []
     if level is None:
         level = 1  # only pick sites with alert
-    response = requests.get(
-        "https://ocean-systems.uc.r.appspot.com/api/collections/heat-stress-tracker",
-        headers=headers,
-    )
+
+    response = requests.get("https://ocean-systems.uc.r.appspot.com/api/sites")
     if response.status_code == 200:
-        for alert_sites in response.json()["sites"]:
-            if alert_sites["sensorId"] is not None:
-                if alert_sites["collectionData"]["alert"] == 0:
+        for alert_sites in response.json():
+            if device == "spotter" and alert_sites["sensorId"] is not None:
+                if alert_sites["collectionData"]["temp_alert"] == 0:
                     alert_level = "no alert"
-                elif alert_sites["collectionData"]["alert"] == 1:
+                elif alert_sites["collectionData"]["temp_alert"] == 1:
                     alert_level = "watch"
-                elif alert_sites["collectionData"]["alert"] == 2:
+                elif alert_sites["collectionData"]["temp_alert"] == 2:
                     alert_level = "warning"
-                elif alert_sites["collectionData"]["alert"] == 3:
+                elif alert_sites["collectionData"]["temp_alert"] == 3:
                     alert_level = "Level-1"
-                elif alert_sites["collectionData"]["alert"] == 4:
+                elif alert_sites["collectionData"]["temp_alert"] == 4:
                     alert_level = "Level-2"
-                if alert_sites["collectionData"]["alert"] >= level:
-                    sid_list.append({alert_sites["name"]: alert_sites["id"]})
+                if alert_sites["collectionData"]["temp_alert"] >= level:
+                    sid_list.append(
+                        [
+                            alert_sites["name"],
+                            alert_sites["id"],
+                            alert_sites["collectionData"]["temp_alert"],
+                        ]
+                    )
                     status_list.append(alert_level)
-    for site in sid_list:
-        for name, sid in site.items():
-            print(f"{name}: {sid}")
-    print(
-        "\n"
-        + f"Found a total of {len(sid_list)} sites with spotters & active alert level >= {level}"
-        + "\n"
-    )
+            elif device == "hobo" and alert_sites["hasHobo"] is True:
+                if alert_sites["collectionData"]["temp_alert"] == 0:
+                    alert_level = "no alert"
+                elif alert_sites["collectionData"]["temp_alert"] == 1:
+                    alert_level = "watch"
+                elif alert_sites["collectionData"]["temp_alert"] == 2:
+                    alert_level = "warning"
+                elif alert_sites["collectionData"]["temp_alert"] == 3:
+                    alert_level = "Level-1"
+                elif alert_sites["collectionData"]["temp_alert"] == 4:
+                    alert_level = "Level-2"
+                if alert_sites["collectionData"]["temp_alert"] >= level:
+                    hobo_list.append(
+                        [
+                            alert_sites["name"],
+                            alert_sites["id"],
+                            alert_sites["collectionData"]["temp_alert"],
+                        ]
+                    )
+                    status_list.append(alert_level)
+            elif device is None:
+                try:
+                    if alert_sites["collectionData"]["temp_alert"] == 0:
+                        alert_level = "no alert"
+                    elif alert_sites["collectionData"]["temp_alert"] == 1:
+                        alert_level = "watch"
+                    elif alert_sites["collectionData"]["temp_alert"] == 2:
+                        alert_level = "warning"
+                    elif alert_sites["collectionData"]["temp_alert"] == 3:
+                        alert_level = "Level-1"
+                    elif alert_sites["collectionData"]["temp_alert"] == 4:
+                        alert_level = "Level-2"
+                    if alert_sites["collectionData"]["temp_alert"] >= level:
+                        overall_list.append(
+                            [
+                                alert_sites["name"],
+                                alert_sites["id"],
+                                alert_sites["collectionData"]["temp_alert"],
+                            ]
+                        )
+                        status_list.append(alert_level)
+                except Exception as e:
+                    print(e)
+    else:
+        sys.exit("\n" + f"Page returned status code :{response.status_code}")
+    if device is not None and device == "spotter":
+        print(
+            "\n"
+            + f"================Spotter Alert Locations & Level >={level}================"
+        )
+        print("\n".join([" : ".join([str(cell) for cell in row])
+              for row in sid_list]))
+        print(
+            "\n"
+            + f"Found a total of {len(sid_list)} sites with spotters & active alert level >= {level}"
+            + "\n"
+        )
+    elif device is not None and device == "hobo":
+        print(
+            "\n" + f"================Hobo Sensor Locations & Level >=1================"
+        )
+        print("\n".join([" : ".join([str(cell) for cell in row])
+              for row in hobo_list]))
+        print(
+            "\n"
+            + f"Found a total of {len(hobo_list)} hobo sensor list sites with active alert level >= {level}"
+            + "\n"
+        )
+    elif device is None:
+        print(
+            "\n"
+            + f"================Overall sites Locations & Level >={level}================"
+        )
+        print(
+            "\n".join([" : ".join([str(cell) for cell in row])
+                      for row in overall_list])
+        )
+        print("\n")
+
     print("Level Key ===> 0: No alert, 1: watch, 2: warning, 3:Level-1, 4:Level-2")
     print("\n" + "Alert level distribution :")
     print(json.dumps(Counter(status_list)))
 
 
 def sitealert_from_parser(args):
-    sitealert(level=args.level)
+    sitealert(level=args.level, device=args.device)
 
 
 # Get a quick check on a site
 def site_info(sid, ext):
-    response = requests.get(f"https://ocean-systems.uc.r.appspot.com/api/sites/{sid}")
+    response = requests.get(
+        f"https://ocean-systems.uc.r.appspot.com/api/sites/{sid}")
     if response.status_code == 200:
-        keys_to_remove = ["admins", "historicalMonthlyMean", "stream", "videoStream"]
+        keys_to_remove = ["admins", "historicalMonthlyMean",
+                          "stream", "videoStream"]
         site_inf = response.json()
         if ext is not None and ext == "historical":
             ext = "historicalMonthlyMean"
@@ -239,7 +332,8 @@ def site_live(sid):
         print(json.dumps(live_data.json(), indent=4))
     else:
         print(
-            "Failed to get live data with error code {}".format(live_data.status_code)
+            "Failed to get live data with error code {}".format(
+                live_data.status_code)
         )
 
 
@@ -285,7 +379,8 @@ def site_daily(delta, sid, dtype):
                     or dset.capitalize() in key
                     or dset.upper() in key
                 }
-                ext_dt = {key: value for key, value in resp.items() if key == "date"}
+                ext_dt = {key: value for key,
+                          value in resp.items() if key == "date"}
                 combined = ext_dt.copy()
                 combined.update(ext)
                 print(json.dumps(combined, indent=2))
@@ -311,7 +406,8 @@ def site_timeseries(delta, sid, dtype, fpath):
     past_utc = past_utc.strftime("%Y-%m-%dT%H:%M:%SZ")
     print(f"Time series from {past_utc} to {current_utc}")
 
-    response = requests.get(f"https://ocean-systems.uc.r.appspot.com/api/sites/{sid}")
+    response = requests.get(
+        f"https://ocean-systems.uc.r.appspot.com/api/sites/{sid}")
     if response.status_code == 200:
         resp = response.json()["polygon"]["coordinates"]
         lng = resp[0]
@@ -336,7 +432,8 @@ def site_timeseries(delta, sid, dtype, fpath):
     else:
         print("Datatype is not supported")
 
-    params = {"start": past_utc, "end": current_utc, "metrics": metrics, "hourly": True}
+    params = {"start": past_utc, "end": current_utc,
+              "metrics": metrics, "hourly": True}
 
     response = requests.get(
         f"https://ocean-systems.uc.r.appspot.com/api/time-series/sites/{sid}",
@@ -369,12 +466,14 @@ def site_timeseries(delta, sid, dtype, fpath):
 
 
 def timeseries_from_parser(args):
-    site_timeseries(sid=args.sid, delta=args.months, dtype=args.dtype, fpath=args.fpath)
+    site_timeseries(sid=args.sid, delta=args.months,
+                    dtype=args.dtype, fpath=args.fpath)
 
 
 # Function to export time series data from site
 def site_argofloats(sid, fpath, start, end, radius):
-    response = requests.get(f"https://ocean-systems.uc.r.appspot.com/api/sites/{sid}")
+    response = requests.get(
+        f"https://ocean-systems.uc.r.appspot.com/api/sites/{sid}")
     if response.status_code == 200:
         resp = response.json()["polygon"]["coordinates"]
         lng = resp[0]
@@ -420,7 +519,8 @@ def main(args=None):
     parser_sitelist = subparsers.add_parser(
         "site-list", help="Print lists of Site Name and ID with spotters"
     )
-    optional_named = parser_sitelist.add_argument_group("Optional named arguments")
+    optional_named = parser_sitelist.add_argument_group(
+        "Optional named arguments")
     optional_named.add_argument("--name", help="Pass site name", default=None)
     optional_named.add_argument(
         "--status",
@@ -432,7 +532,8 @@ def main(args=None):
     parser_sitealert = subparsers.add_parser(
         "site-alert", help="Print site alerts for sites with spotters"
     )
-    optional_named = parser_sitealert.add_argument_group("Optional named arguments")
+    optional_named = parser_sitealert.add_argument_group(
+        "Optional named arguments")
     optional_named.add_argument(
         "--level",
         help="Level 0-4 no-alert|watch|warning|Level-1|Level-2",
@@ -440,14 +541,21 @@ def main(args=None):
         type=int,
         choices=range(0, 5),
     )
+    optional_named.add_argument(
+        "--device",
+        help="spotter|hobo",
+        default=None,
+    )
     parser_sitealert.set_defaults(func=sitealert_from_parser)
 
     parser_siteinfo = subparsers.add_parser(
         "site-info", help="Print detailed information for a site"
     )
-    required_named = parser_siteinfo.add_argument_group("Required named arguments.")
+    required_named = parser_siteinfo.add_argument_group(
+        "Required named arguments.")
     required_named.add_argument("--sid", help="Site ID", required=True)
-    optional_named = parser_siteinfo.add_argument_group("Optional named arguments")
+    optional_named = parser_siteinfo.add_argument_group(
+        "Optional named arguments")
     optional_named.add_argument(
         "--extra", help="extra info keywords: historical/admins", default=None
     )
@@ -456,16 +564,19 @@ def main(args=None):
     parser_sitelive = subparsers.add_parser(
         "site-live", help="Get most recent/live info from a site"
     )
-    required_named = parser_sitelive.add_argument_group("Required named arguments.")
+    required_named = parser_sitelive.add_argument_group(
+        "Required named arguments.")
     required_named.add_argument("--sid", help="Site ID", required=True)
     parser_sitelive.set_defaults(func=sitelive_from_parser)
 
     parser_sitedaily = subparsers.add_parser(
         "site-daily", help="Print daily data info for a site"
     )
-    required_named = parser_sitedaily.add_argument_group("Required named arguments.")
+    required_named = parser_sitedaily.add_argument_group(
+        "Required named arguments.")
     required_named.add_argument("--sid", help="Site ID", required=True)
-    optional_named = parser_sitedaily.add_argument_group("Optional named arguments")
+    optional_named = parser_sitedaily.add_argument_group(
+        "Optional named arguments")
     optional_named.add_argument(
         "--months", help="Total number of months from today", default=None
     )
@@ -477,10 +588,13 @@ def main(args=None):
     parser_timeseries = subparsers.add_parser(
         "site-timeseries", help="Exports timeseries data for a site"
     )
-    required_named = parser_timeseries.add_argument_group("Required named arguments.")
+    required_named = parser_timeseries.add_argument_group(
+        "Required named arguments.")
     required_named.add_argument("--sid", help="Site ID", required=True)
-    required_named.add_argument("--fpath", help="Folder path for export", required=True)
-    optional_named = parser_timeseries.add_argument_group("Optional named arguments")
+    required_named.add_argument(
+        "--fpath", help="Folder path for export", required=True)
+    optional_named = parser_timeseries.add_argument_group(
+        "Optional named arguments")
     optional_named.add_argument(
         "--months", help="Total number of months from today", default=None
     )
@@ -495,7 +609,8 @@ def main(args=None):
     parser_argo = subparsers.add_parser(
         "site-argo", help="Exports coincident argofloat data for a site"
     )
-    required_named = parser_argo.add_argument_group("Required named arguments.")
+    required_named = parser_argo.add_argument_group(
+        "Required named arguments.")
     required_named.add_argument("--sid", help="Site ID", required=True)
     required_named.add_argument(
         "--start", help="Start date in format YYYY-MM-DD", required=True
@@ -503,7 +618,8 @@ def main(args=None):
     required_named.add_argument(
         "--end", help="End date in format YYYY-MM-DD", required=True
     )
-    required_named.add_argument("--fpath", help="Folder path for export", required=True)
+    required_named.add_argument(
+        "--fpath", help="Folder path for export", required=True)
     optional_named = parser_argo.add_argument_group("Optional named arguments")
     optional_named.add_argument(
         "--radius", help="Search radius in kilometers", default=None
